@@ -1,5 +1,5 @@
 from lxml import etree
-from vgmdb.xpaths import main_xpaths_dict
+from pyvgmdb.xpaths import main_xpaths_dict
 
 
 class SafeEtree:
